Applicability

Enum Applicability 

pub enum Applicability {
    DisplayOnly,
    Unsafe,
    Safe,
}
Indicates if a fix can be applied.

Variants



DisplayOnly

The fix is unsafe and should only be displayed for manual application by the user.

The fix is likely to be incorrect or the resulting code may have invalid syntax.



Unsafe

The fix is unsafe and should only be applied with user opt-in.

The fix may be what the user intended, but it is uncertain. The resulting code will have valid syntax, but may lead to a change in runtime behavior, the removal of user comments, or both.



Safe

The fix is safe and can always be applied.

The fix is definitely what the user intended, or maintains the exact meaning of the code. User comments are preserved, unless the fix removes an entire statement or expression.

Implementations

Source

impl Applicability

pub const fn is_display_only(&self) -> bool

Returns true if self is of variant DisplayOnly.

pub const fn is_unsafe(&self) -> bool

Returns true if self is of variant Unsafe.

pub const fn is_safe(&self) -> bool

Returns true if self is of variant Safe.