pub enum IsolationLevel {
Group(u32),
NonOverlapping,
}Expand description
Indicates the level of isolation required to apply a fix.
Variants
Group(u32)
The fix should be applied as long as no other fixes in the same group have been applied.
NonOverlapping
The fix should be applied as long as it does not overlap with any other fixes.