pub struct Edit { /* private fields */ }Expand description
A text edit to be applied to a source file. Inserts, deletes, or replaces content at a given location.
Implementations
Sourceimpl Edit
impl Edit
Sourcepub const fn deletion(start: TextSize, end: TextSize) -> Self
pub const fn deletion(start: TextSize, end: TextSize) -> Self
Creates an edit that deletes the content in the start to end range.
Sourcepub const fn range_deletion(range: TextRange) -> Self
pub const fn range_deletion(range: TextRange) -> Self
Creates an edit that deletes the content in range.
Sourcepub fn replacement(content: String, start: TextSize, end: TextSize) -> Self
pub fn replacement(content: String, start: TextSize, end: TextSize) -> Self
Creates an edit that replaces the content in the start to end range with content.
Sourcepub fn range_replacement(content: String, range: TextRange) -> Self
pub fn range_replacement(content: String, range: TextRange) -> Self
Creates an edit that replaces the content in range with content.
Sourcepub fn insertion(content: String, at: TextSize) -> Self
pub fn insertion(content: String, at: TextSize) -> Self
Creates an edit that inserts content at the TextSize at.
pub fn into_content(self) -> Option<Box<str>>
Sourcepub fn is_deletion(&self) -> bool
pub fn is_deletion(&self) -> bool
Returns true if this edit deletes content from the source document.
Sourcepub fn is_insertion(&self) -> bool
pub fn is_insertion(&self) -> bool
Returns true if this edit inserts new content into the source document.
Sourcepub fn is_replacement(&self) -> bool
pub fn is_replacement(&self) -> bool
Returns true if this edit replaces some existing content with new content.