Fix

Struct Fix 

pub struct Fix { /* private fields */ }
A collection of Edit elements to be applied to a source file.

Implementations

Source

impl Fix

pub fn safe_edit(edit: Edit) -> Self

Create a new Fix that is safe to apply from an Edit element.

pub fn safe_edits(edit: Edit, rest: impl IntoIterator<Item = Edit>) -> Self

Create a new Fix that is safe to apply from multiple Edit elements.

pub fn unsafe_edit(edit: Edit) -> Self

Create a new Fix that is unsafe to apply from an Edit element.

pub fn unsafe_edits(edit: Edit, rest: impl IntoIterator<Item = Edit>) -> Self

Create a new Fix that is unsafe to apply from multiple Edit elements.

pub fn display_only_edit(edit: Edit) -> Self

Create a new Fix that should only display and not apply from an Edit element .

pub fn applicable_edit(edit: Edit, applicability: Applicability) -> Self

Create a new Fix with the specified Applicability to apply an Edit element.

pub fn applicable_edits( edit: Edit, rest: impl IntoIterator<Item = Edit>, applicability: Applicability, ) -> Self

Create a new Fix with the specified Applicability to apply multiple Edit elements.

pub fn min_start(&self) -> Option<TextSize>

Return the TextSize of the first Edit in the Fix.

pub fn edits(&self) -> &[Edit]

Return a slice of the Edit elements in the Fix, sorted by Edit::start in ascending order.

pub fn into_edits(self) -> Vec<Edit>

pub fn applicability(&self) -> Applicability

Return the Applicability of the Fix.

pub fn isolation(&self) -> IsolationLevel

Return the IsolationLevel of the Fix.

pub fn isolate(self, isolation: IsolationLevel) -> Self

Create a new Fix with the given IsolationLevel.

pub fn applies(&self, applicability: Applicability) -> bool

Return true if this Fix should be applied with at a given Applicability.

pub fn with_applicability(self, applicability: Applicability) -> Self

Create a new Fix with the given Applicability.