pub struct SourceMap(/* private fields */);Expand description
A collection of SourceMarker.
Sourcemaps are used to map positions in the original source to positions in the transformed code. Here, only the boundaries of edits are tracked instead of every single character.
This mapping maintains the invariant that markers are in source order.
Implementations
Sourceimpl SourceMap
impl SourceMap
Sourcepub fn markers(&self) -> &[SourceMarker]
pub fn markers(&self) -> &[SourceMarker]
Returns a slice of all the markers in the sourcemap in source order.
Sourcepub fn push_start_marker(&mut self, edit: &Edit, output_length: TextSize)
pub fn push_start_marker(&mut self, edit: &Edit, output_length: TextSize)
Sourcepub fn push_end_marker(&mut self, edit: &Edit, output_length: TextSize)
pub fn push_end_marker(&mut self, edit: &Edit, output_length: TextSize)
Sourcepub fn push_marker(&mut self, offset: TextSize, output_length: TextSize)
pub fn push_marker(&mut self, offset: TextSize, output_length: TextSize)