Edit

Struct Edit 

pub struct Edit { /* private fields */ }
A text edit to be applied to a source file. Inserts, deletes, or replaces content at a given location.

Implementations

Source

impl Edit

pub const fn deletion(start: TextSize, end: TextSize) -> Self

Creates an edit that deletes the content in the start to end range.

pub const fn range_deletion(range: TextRange) -> Self

Creates an edit that deletes the content in range.

pub fn replacement(content: String, start: TextSize, end: TextSize) -> Self

Creates an edit that replaces the content in the start to end range with content.

pub fn range_replacement(content: String, range: TextRange) -> Self

Creates an edit that replaces the content in range with content.

pub fn insertion(content: String, at: TextSize) -> Self

Creates an edit that inserts content at the TextSize at.

pub fn content(&self) -> Option<&str>

Returns the new content for an insertion or deletion.

pub fn into_content(self) -> Option<Box<str>>

pub fn is_deletion(&self) -> bool

Returns true if this edit deletes content from the source document.

pub fn is_insertion(&self) -> bool

Returns true if this edit inserts new content into the source document.

pub fn is_replacement(&self) -> bool

Returns true if this edit replaces some existing content with new content.