pub struct Fix { /* private fields */ }Expand description
A collection of Edit elements to be applied to a source file.
Implementations
Sourceimpl Fix
impl Fix
Sourcepub fn safe_edits(edit: Edit, rest: impl IntoIterator<Item = Edit>) -> Self
pub fn safe_edits(edit: Edit, rest: impl IntoIterator<Item = Edit>) -> Self
Sourcepub fn unsafe_edit(edit: Edit) -> Self
pub fn unsafe_edit(edit: Edit) -> Self
Sourcepub fn unsafe_edits(edit: Edit, rest: impl IntoIterator<Item = Edit>) -> Self
pub fn unsafe_edits(edit: Edit, rest: impl IntoIterator<Item = Edit>) -> Self
Sourcepub fn display_only_edit(edit: Edit) -> Self
pub fn display_only_edit(edit: Edit) -> Self
Sourcepub fn applicable_edit(edit: Edit, applicability: Applicability) -> Self
pub fn applicable_edit(edit: Edit, applicability: Applicability) -> Self
Create a new Fix with the specified Applicability to apply an Edit element.
Sourcepub fn applicable_edits(
edit: Edit,
rest: impl IntoIterator<Item = Edit>,
applicability: Applicability,
) -> Self
pub fn applicable_edits( edit: Edit, rest: impl IntoIterator<Item = Edit>, applicability: Applicability, ) -> Self
Create a new Fix with the specified Applicability to apply multiple Edit elements.
Sourcepub fn edits(&self) -> &[Edit]
pub fn edits(&self) -> &[Edit]
Return a slice of the Edit elements in the Fix, sorted by Edit::start in ascending order.
pub fn into_edits(self) -> Vec<Edit>
Sourcepub fn applicability(&self) -> Applicability
pub fn applicability(&self) -> Applicability
Return the Applicability of the Fix.
Sourcepub fn isolation(&self) -> IsolationLevel
pub fn isolation(&self) -> IsolationLevel
Return the IsolationLevel of the Fix.
Sourcepub fn isolate(self, isolation: IsolationLevel) -> Self
pub fn isolate(self, isolation: IsolationLevel) -> Self
Create a new Fix with the given IsolationLevel.
Sourcepub fn applies(&self, applicability: Applicability) -> bool
pub fn applies(&self, applicability: Applicability) -> bool
Return true if this Fix should be applied with at a given Applicability.
Sourcepub fn with_applicability(self, applicability: Applicability) -> Self
pub fn with_applicability(self, applicability: Applicability) -> Self
Create a new Fix with the given Applicability.