SourceMap

Struct SourceMap 

pub struct SourceMap(/* private fields */);
A collection of SourceMarker.

Sourcemaps are used to map positions in the original source to positions in the transformed code. Here, only the boundaries of edits are tracked instead of every single character.

This mapping maintains the invariant that markers are in source order.

Implementations

Source

impl SourceMap

pub fn markers(&self) -> &[SourceMarker]

Returns a slice of all the markers in the sourcemap in source order.

pub fn push_start_marker(&mut self, edit: &Edit, output_length: TextSize)

Push the start marker for an Edit.

The output_length is the length of the transformed string before the edit is applied.

Panics

If the start of edit is less than previous markers.

pub fn push_end_marker(&mut self, edit: &Edit, output_length: TextSize)

Push the end marker for an Edit.

The output_length is the length of the transformed string after the edit has been applied.

Panics

If edit falls before previous markers.

pub fn push_marker(&mut self, offset: TextSize, output_length: TextSize)

Push a new marker to the sourcemap.

Panics

If offset is less than previous markers.